==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/RFQLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RFQLINEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RFQLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONREQUESTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQLINEID_Type", propOrder = {
    "quotationrequestid",
    "rfqlinenum"
})
public class RFQLINEID_Type {

    @XmlElement(name = "QUOTATIONREQUESTID", required = true)
    protected QUOTATIONREQUESTID_Type quotationrequestid;
    @XmlElement(name = "RFQLINENUM")
    protected long rfqlinenum;

    /**
     * Obtient la valeur de la propriété quotationrequestid.
     * 
     * @return
     *     possible object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public QUOTATIONREQUESTID_Type getQUOTATIONREQUESTID() {
        return quotationrequestid;
    }

    /**
     * Définit la valeur de la propriété quotationrequestid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public void setQUOTATIONREQUESTID(QUOTATIONREQUESTID_Type value) {
        this.quotationrequestid = value;
    }

    /**
     * Obtient la valeur de la propriété rfqlinenum.
     * 
     */
    public long getRFQLINENUM() {
        return rfqlinenum;
    }

    /**
     * Définit la valeur de la propriété rfqlinenum.
     * 
     */
    public void setRFQLINENUM(long value) {
        this.rfqlinenum = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RFQLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RFQLINEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RFQLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONREQUESTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQLINEID_Type", propOrder = {
    "quotationrequestid",
    "rfqlinenum"
})
public class RFQLINEID_Type {

    @XmlElement(name = "QUOTATIONREQUESTID", required = true)
    protected QUOTATIONREQUESTID_Type quotationrequestid;
    @XmlElement(name = "RFQLINENUM")
    protected long rfqlinenum;

    /**
     * Gets the value of the quotationrequestid property.
     * 
     * @return
     *     possible object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public QUOTATIONREQUESTID_Type getQUOTATIONREQUESTID() {
        return quotationrequestid;
    }

    /**
     * Sets the value of the quotationrequestid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public void setQUOTATIONREQUESTID(QUOTATIONREQUESTID_Type value) {
        this.quotationrequestid = value;
    }

    /**
     * Gets the value of the rfqlinenum property.
     * 
     */
    public long getRFQLINENUM() {
        return rfqlinenum;
    }

    /**
     * Sets the value of the rfqlinenum property.
     * 
     */
    public void setRFQLINENUM(long value) {
        this.rfqlinenum = value;
    }

}
